==> eclipse-2.1.3_1.tgz: org/eclipse/pde/core/plugin/IPluginImport.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2003 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.pde.core.plugin;

import org.eclipse.core.runtime.CoreException;
/**
 * Objects that implement this interface represent references
 * to required plug-ins.
 * <p>
 * <b>Note:</b> This interface is part of an interim API that is still under development and expected to
 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
 * (repeatedly) as the API evolves.
 * </p>
 */
public interface IPluginImport extends IPluginObject, IPluginReference {
	/**
	 * A name of the property that will be used to notify
	 * about changes in the "reexported" field.
	 * <p>
	 * <b>Note:</b> This field is part of an interim API that is still under development and expected to
	 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
	 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
	 * (repeatedly) as the API evolves.
	 * </p>
	 */
	public static final String P_REEXPORTED = "reexported";
	/**
	 * A name of the property that will be used to notify
	 * about changes in the "optional" field.
	 * <p>
	 * <b>Note:</b> This field is part of an interim API that is still under development and expected to
	 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
	 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
	 * (repeatedly) as the API evolves.
	 * </p>
	 */
	public static final String P_OPTIONAL = "optional";
	/**
	 * Tests whether the imported plug-in is reexported for
	 * plug-ins that will use this plug-in.
	 *
	 * @return true if the required plug-in libraries are reexported
	 * <p>
	 * <b>Note:</b> This method is part of an interim API that is still under development and expected to
	 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
	 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
	 * (repeatedly) as the API evolves.
	 * </p>
	 */
	public boolean isReexported();
	/**
	 * Tests whether this import is optional. Optional imports will
	 * not create an error condition when they cannot be resolved.
	 *
	 * @return true if this import is optional
	 * <p>
	 * <b>Note:</b> This method is part of an interim API that is still under development and expected to
	 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
	 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
	 * (repeatedly) as the API evolves.
	 * </p>
	 */
	public boolean isOptional();
	/**
	 * Sets whether the libraries of the required plug-in will
	 * be reexported.
	 * This method will throw a CoreException if the model
	 * is not editable.
	 *
	 * @param value true if reexporting is desired
	 * <p>
	 * <b>Note:</b> This method is part of an interim API that is still under development and expected to
	 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
	 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
	 * (repeatedly) as the API evolves.
	 * </p>
	 */
	public void setReexported(boolean value) throws CoreException;
	/**
	 * Sets whether this import is optional. Optional imports will
	 * not create an error condition when they cannot be resolved.
	 *
	 * @param value true if import is optional
	 * <p>
	 * <b>Note:</b> This method is part of an interim API that is still under development and expected to
	 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
	 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
	 * (repeatedly) as the API evolves.
	 * </p>
	 */
	public void setOptional(boolean value) throws CoreException;
}

==> eclipse-3.0.1_2.tgz: org/eclipse/pde/core/plugin/IPluginImport.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.pde.core.plugin;

import org.eclipse.core.runtime.*;
/**
 * Objects that implement this interface represent references
 * to required plug-ins.
 */
public interface IPluginImport extends IPluginObject, IPluginReference {
	/**
	 * A name of the property that will be used to notify
	 * about changes in the "reexported" field.
	 */
	String P_REEXPORTED = "export"; //$NON-NLS-1$
	/**
	 * A name of the property that will be used to notify
	 * about changes in the "optional" field.
	 */
	String P_OPTIONAL = "optional"; //$NON-NLS-1$
	/**
	 * Tests whether the imported plug-in is reexported for
	 * plug-ins that will use this plug-in.
	 *
	 * @return true if the required plug-in libraries are reexported
	 */
	boolean isReexported();
	/**
	 * Tests whether this import is optional. Optional imports will
	 * not create an error condition when they cannot be resolved.
	 *
	 * @return true if this import is optional
	 */
	boolean isOptional();
	/**
	 * Sets whether the libraries of the required plug-in will
	 * be reexported.
	 * This method will throw a CoreException if the model
	 * is not editable.
	 *
	 * @param value true if reexporting is desired
	 */
	void setReexported(boolean value) throws CoreException;
	/**
	 * Sets whether this import is optional. Optional imports will
	 * not create an error condition when they cannot be resolved.
	 *
	 * @param value true if import is optional
	 */
	void setOptional(boolean value) throws CoreException;
}
